@@ -24,6 +24,8 @@ nimbleUserNamespace <- as.environment(list(sessionSpecificDll = NULL))
         pauseAfterWritingFiles = FALSE,
         CppAD_directory = NA,
         experimentalEnableDerivs = FALSE,
+        determinePredictiveNodesInModel = TRUE,
+        getDependenciesIncludesPredictiveNodes = TRUE,    ## may be toggled off during MCMC sampler building
         convertSingleVectorsToScalarsInSetupArgs = TRUE,
         messagesWhenBuildingOrFinalizingCppObjects = FALSE,
         indexDrop = TRUE,
@@ -57,7 +59,10 @@ nimbleUserNamespace <- as.environment(list(sessionSpecificDll = NULL))
         MCMCmultivariateNodesAsScalars = FALSE,
         MCMCmonitorAllSampledNodes = FALSE,
         MCMCuseConjugacy = TRUE,
-        MCMCjointlySamplePredictiveBranches = TRUE,
+        MCMCorderPosteriorPredictiveSamplersLast = TRUE,
+        MCMCusePredictiveDependenciesInCalculations = FALSE,
+        MCMCusePosteriorPredictiveSampler = TRUE,
+        MCMCwarnUnsampledStochasticNodes = TRUE,
         MCMCRJcheckHyperparam = TRUE,
         MCMCenableWAIC = FALSE
         
